==> aws-cdk.aws-mediastore-1.123.0.tar.gz: package/lib/mediastore-canned-metrics.generated.d.ts <==
export declare class MediaStoreMetrics {
    static requestCountSum(dimensions: {
        ContainerName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ContainerName: string;
        };
        statistic: string;
    };
    static turnaroundTimeAverage(dimensions: {
        ContainerName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ContainerName: string;
        };
        statistic: string;
    };
    static _4XxErrorCountSum(dimensions: {
        ContainerName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ContainerName: string;
        };
        statistic: string;
    };
    static _5XxErrorCountSum(dimensions: {
        ContainerName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ContainerName: string;
        };
        statistic: string;
    };
    static bytesDownloadedSum(dimensions: {
        ContainerName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ContainerName: string;
        };
        statistic: string;
    };
    static bytesUploadedSum(dimensions: {
        ContainerName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ContainerName: string;
        };
        statistic: string;
    };
    static totalTimeAverage(dimensions: {
        ContainerName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ContainerName: string;
        };
        statistic: string;
    };
}

==> aws-cdk.aws-mediastore-1.164.0.tar.gz: package/lib/mediastore-canned-metrics.generated.d.ts <==
export declare class MediaStoreMetrics {
    static requestCountSum(dimensions: {
        ContainerName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ContainerName: string;
        };
        statistic: string;
    };
    static turnaroundTimeAverage(dimensions: {
        ContainerName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ContainerName: string;
        };
        statistic: string;
    };
    static _4XxErrorCountSum(dimensions: {
        ContainerName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ContainerName: string;
        };
        statistic: string;
    };
    static _5XxErrorCountSum(dimensions: {
        ContainerName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ContainerName: string;
        };
        statistic: string;
    };
    static bytesDownloadedSum(dimensions: {
        ContainerName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ContainerName: string;
        };
        statistic: string;
    };
    static bytesUploadedSum(dimensions: {
        ContainerName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ContainerName: string;
        };
        statistic: string;
    };
    static totalTimeAverage(dimensions: {
        ContainerName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ContainerName: string;
        };
        statistic: string;
    };
}
